@@ -77,7 +77,7 @@ def procesamiento_aseguradoras(date_port, port_name, ruta, ruta_precia, portfoli
 
     # AJUSTAR ESTA LINEA CUANDO LLEGUEN NOMBRES DE PORTAFOLIOS.
     # Quemamos codigo PORTFOLIO = PATRIMONIO.
-    Portafolio['PORTAFOLIO'] = np.where(Portafolio['PORTAFOLIO']=="OBL-RETIRO","RENTAS_VITALICIAS",Portafolio['PORTAFOLIO'])
+    # Portafolio['PORTAFOLIO'] = np.where(Portafolio['PORTAFOLIO']=="OBL-RETIRO","RENTAS_VITALICIAS",Portafolio['PORTAFOLIO'])
     Portafolio['CALIFICACION DEL TITULO O DEL EMISOR'] = np.where(Portafolio['CALIFICACION DEL TITULO O DEL EMISOR'].isnull(),"NA",Portafolio['CALIFICACION DEL TITULO O DEL EMISOR'])
 
     PortafolioDP=Portafolio[-Portafolio["CLASE DE INVERSION"].isin(["TSTF","TSUV"])]
@@ -288,8 +288,11 @@ def procesamiento_aseguradoras(date_port, port_name, ruta, ruta_precia, portfoli
     df_aladdin = pd.DataFrame(columns=portfolio_fields['Fields'].dropna().unique().tolist())
     Portafolio = df_aladdin.append(Portafolio, ignore_index=True)
 
-    # Asigno subgroup y portfolioName(quemados).
-    Portafolio['subGroup'] = subGroup
+    # Asigno subgroup en base a condiciones, portfolioName queda quemados con parametro.    
+    condiciones = [(Portafolio.portfolioName == 'SU25'), (Portafolio.portfolioName == 'SU26'), (Portafolio.portfolioName == 'SU29')]
+    valores = ('PATRIMONIO', 'RENTAS VITALICIAS', 'SEGURO PREVISIONAL')
+    Portafolio['subGroup'] = np.select(condiciones, valores, subGroup)
+
     Portafolio['portfolioName'] = portfolioName
 
     # Ajuste YTM
